@@ -1,5 +1,3 @@
-/* $Id: write.c 2478 2006-04-10 08:41:46Z bdejean $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -22,7 +20,7 @@
 */
 
 #include <config.h>
-
+#include <errno.h>
 #include <glibtop/write.h>
 #include <glibtop/error.h>
 #include <glib/gi18n-lib.h>
@@ -33,6 +31,7 @@ void
 glibtop_write_l (glibtop *server, size_t size, void *buf)
 {
 	int ret;
+	int fd;
 
 	glibtop_init_r (&server, 0, 0);
 
@@ -42,11 +41,10 @@ glibtop_write_l (glibtop *server, size_t size, void *buf)
 	fprintf (stderr, "LIBRARY: really writing %d bytes.\n", (int)size);
 #endif
 
-	if (server->socket) {
-		ret = send (server->socket, buf, size, 0);
-	} else {
-		ret = write (server->output [1], buf, size);
-	}
+	fd = server->socket ? server->socket : server->output[1];
+
+	while ((ret = write(fd, buf, size)) < 0 && errno == EINTR)
+		;
 
 	if (ret < 0)
 		glibtop_error_io_r (server,
