@@ -38,7 +38,7 @@ static const unsigned long _glibtop_sysdeps_proc_segment =
 /* Init function. */
 
 void
-glibtop_init_proc_segment_s (glibtop *server)
+_glibtop_init_proc_segment_s (glibtop *server)
 {
 	server->sysdeps.proc_segment = _glibtop_sysdeps_proc_segment;
 }
