@@ -1,5 +1,3 @@
-/* $Id: open.c 2323 2005-03-25 13:25:01Z bdejean $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -22,7 +20,7 @@
 */
 
 #include <config.h>
-#include <glib/gstrfuncs.h>
+#include <glib.h>
 #include <errno.h>
 
 #include <glibtop.h>
